"""Infrastructure adapters for prompt management."""

from globkurier_mcp.infrastructure.prompts.json_prompt_repository import (
    JsonPromptRepository,
)

__all__ = [
    "JsonPromptRepository",
]
